strchr

Function strchr 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn strchr( s: *const c_char, c: c_int, ) -> *mut c_char
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/strchr.html.

Safety

The caller is required to ensure that s is a valid pointer to a buffer containing at least one nul value. The pointed-to buffer must not be modified for the duration of the call.