#[unsafe(no_mangle)]pub unsafe extern "C" fn memccpy(
s1: *mut c_void,
s2: *const c_void,
c: c_int,
n: size_t,
) -> *mut c_voidExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/memccpy.html.
Safety
The caller must ensure that:
nis not longer than the memory area pointed to bys1, andnis not longer than the memory area pointed to bys2.